# Playground

### Instaling Requirements

```
python -m venv env
source env/bin/activate
pip install -r requirements.txt
```

### Running

```
python src/main.py
```

### Testing

```
pytest --cov
```
